@@ -142,7 +142,7 @@ protected:
     /** Set to true if the item should be moved alone (without other selected items) */
     void setExclusiveMoving(bool value) { _exclusiveMoving = value; }
 
-    /** Set custum test for undo command for moving item. Works only if exclusiveMoving is true */
+    /** Set custom test for undo command for moving item. Works only if exclusiveMoving is true */
     void setExclusiveMovingMessage(const QString& message) { _exclusiveMovingMessage = message; }
 
     /** Called when graphicsitem is changed */
@@ -152,7 +152,7 @@ protected:
     bool isOnHoverHandlerEnabled() const { return _onHoverHandlerEnabled; }
 
     /** Set to true in order to enable on-hover handler.
-     *  \note You should also call setAcceptsHoverEvents(true) in order
+     *  \note You should also call setAcceptHoverEvents(true) in order
      *  for on-hover handler to work */
     void setOnHoverHandlerEnabled(bool enabled);
 
@@ -207,7 +207,7 @@ protected:
     static const int JOINT_ZVALUE = 400;    ///< Default ZValue for joints
     static const int HANDLER_ZVALUE = 800;  ///< Default ZValue for handlers
 
-    static const int COLOR_HIGHLIGHT_AMOUNT = 30; ///< Highligh amount (in percent for value component)
+    static const int COLOR_HIGHLIGHT_AMOUNT = 30; ///< Highlight amount (in percent for value component)
 };
 
 /////////////////////////////////////////////////////////////////////////////////////////
