@@ -33,43 +33,45 @@
 #include "worldscene.h"
 #include "worldfactory.h"
 #include "latexformula.h"
-#include <QItemSelectionModel>
-#include <QGraphicsSceneMouseEvent>
-#include <QStyleOptionGraphicsItem>
-#include <QGraphicsScene>
-#include <QGraphicsView>
-#include <QTextDocument>
+#include <QAbstractButton>
 #include <QAbstractTextDocumentLayout>
-#include <QEvent>
-#include <QPainter>
-#include <QGridLayout>
-#include <QLabel>
-#include <QLCDNumber>
-#include <QFocusEvent>
-#include <QApplication>
 #include <QAction>
-#include <QUrl>
+#include <QApplication>
+#include <QColorDialog>
 #include <QDialog>
 #include <QDialogButtonBox>
-#include <QAbstractButton>
+#include <QEvent>
+#include <QFileDialog>
+#include <QFocusEvent>
+#include <QGraphicsScene>
+#include <QGraphicsSceneMouseEvent>
+#include <QGraphicsView>
+#include <QGridLayout>
+#include <QInputDialog>
+#include <QItemSelectionModel>
+#include <QLCDNumber>
+#include <QLabel>
+#include <QPainter>
 #include <QPushButton>
+#include <QStyleOptionGraphicsItem>
+#include <QTemporaryFile>
+#include <QTextDocument>
+#include <QUrl>
 #include <QVBoxLayout>
 
-#include <KToolBar>
-#include <KPlotWidget>
-#include <KPlotObject>
-#include <KPlotPoint>
-#include <KPlotAxis>
-#include <KFileDialog>
-#include <KProgressDialog>
-#include <KToggleAction>
 #include <KFontAction>
 #include <KFontSizeAction>
-#include <KColorDialog>
+#include <KIO/CopyJob>
+#include <KIO/Job>
+#include <KJobWidgets>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KInputDialog>
-#include <KIO/NetAccess>
+#include <KPlotAxis>
+#include <KPlotObject>
+#include <KPlotPoint>
+#include <KPlotWidget>
+#include <KToggleAction>
+#include <KToolBar>
 
 #include <float.h>
 
@@ -131,7 +133,7 @@ WidgetGraphicsItem::WidgetGraphicsItem(StepCore::Item* item, WorldModel* worldMo
 {
     setFlag(QGraphicsItem::ItemIsSelectable);
     setFlag(QGraphicsItem::ItemIsMovable);
-    setAcceptsHoverEvents(true);
+    setAcceptHoverEvents(true);
 
     _backgroundBrush = Qt::NoBrush;
 
@@ -367,7 +369,7 @@ NoteGraphicsItem::NoteGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     Q_ASSERT(dynamic_cast<StepCore::Note*>(_item) != NULL);
     setFlag(QGraphicsItem::ItemIsSelectable);
     setFlag(QGraphicsItem::ItemIsMovable);
-    setAcceptsHoverEvents(true);
+    setAcceptHoverEvents(true);
 
     _widget = new QWidget();
     _widget->setPalette(QPalette(Qt::lightGray));
@@ -428,13 +430,13 @@ NoteGraphicsItem::NoteGraphicsItem(StepCore::Item* item, WorldModel* worldModel)
     connect(_actionItalic, SIGNAL(triggered(bool)), _textEdit, SLOT(setFontItalic(bool)));
     connect(_actionUnderline, SIGNAL(triggered(bool)), _textEdit, SLOT(setFontUnderline(bool)));
     connect(_actionAlign, SIGNAL(triggered(QAction*)), this, SLOT(formatAlign(QAction*)));
-    connect(_actionFont, SIGNAL(triggered(const QString&)), this, SLOT(formatFontFamily(const QString&)));
+    connect(_actionFont, SIGNAL(triggered(QString)), this, SLOT(formatFontFamily(QString)));
     connect(_actionFontSize, SIGNAL(fontSizeChanged(int)), this, SLOT(formatFontSize(int)));
     connect(_actionInsertImage, SIGNAL(triggered(bool)), this, SLOT(insertImage()));
     connect(_actionInsertFormula, SIGNAL(triggered(bool)), this, SLOT(insertFormula()));
     
-    connect(_textEdit, SIGNAL(currentCharFormatChanged(const QTextCharFormat&)),
-                            this, SLOT(currentCharFormatChanged(const QTextCharFormat&)));
+    connect(_textEdit, SIGNAL(currentCharFormatChanged(QTextCharFormat)),
+                            this, SLOT(currentCharFormatChanged(QTextCharFormat)));
     connect(_textEdit, SIGNAL(cursorPositionChanged()), this, SLOT(cursorPositionChanged()));
 
 
@@ -565,8 +567,8 @@ bool NoteGraphicsItem::eventFilter(QObject* obj, QEvent* event)
 void NoteGraphicsItem::formatColor()
 {
     QColor color = _textEdit->textColor();
-    int result = KColorDialog::getColor(color, _widget);
-    if(result == KColorDialog::Accepted) {
+    color = QColorDialog::getColor(color, _widget);
+    if(QColorDialog::Accepted && color.isValid()) {
         _textEdit->setTextColor(color);
     }
 }
@@ -637,29 +639,25 @@ void NoteGraphicsItem::cursorPositionChanged()
 
 void NoteGraphicsItem::insertImage()
 {
-    QUrl url = KFileDialog::getOpenUrl(QUrl(), "image/png image/jpeg", _widget);
+    QUrl url = QFileDialog::getOpenFileUrl(_widget, i18n("Open Image File"), QUrl(), i18n("Images (*.png *.jpg *.jpeg)"));
     if(url.isEmpty()) return;
 
-    QString tmpFileName;
-    if(! KIO::NetAccess::download(url, tmpFileName, _widget) ) {
-        KMessageBox::error(_widget, KIO::NetAccess::lastErrorString());
+    QTemporaryFile tempFile;
+    tempFile.open();
+    KIO::FileCopyJob *job = KIO::file_copy(url, QUrl::fromLocalFile(tempFile.fileName()), -1, KIO::Overwrite);
+    KJobWidgets::setWindow(job, _widget);
+    job->exec();
+    if (job->error()) {
+        KMessageBox::error(_widget, job->errorString());
         return;
     }
 
-    QFile file(tmpFileName);
-    if(!file.open(QIODevice::ReadOnly)) {
-        KMessageBox::error(_widget, i18n("Cannot open file '%1'", tmpFileName));
-        KIO::NetAccess::removeTempFile(tmpFileName);
-        return;
-    }
-
-    QByteArray data = file.readAll();
-    file.close();
-    KIO::NetAccess::removeTempFile(tmpFileName);
+    QByteArray data = tempFile.readAll();
+    tempFile.close();
 
     QPixmap pixmap;
     if(!pixmap.loadFromData(data)) {
-        KMessageBox::error(_widget, i18n("Cannot parse file '%1'", tmpFileName));
+        KMessageBox::error(_widget, i18n("Cannot parse file '%1'", tempFile.fileName()));
         return;
     }
 
@@ -709,8 +707,8 @@ bool NoteGraphicsItem::editFormula(StepCore::NoteFormula* formula)
     }
 
     bool ok;
-    QString code = KInputDialog::getMultiLineText(i18n("LaTex Formula - Step"),
-                i18n("Enter LaTeX formula string"), QString(formula->code()), &ok, _widget);
+    QString code = QInputDialog::getMultiLineText(_widget, i18n("LaTex Formula - Step"),
+                i18n("Enter LaTeX formula string"), QString(formula->code()), &ok);
     if(!ok) return false;
 
     QByteArray image;
@@ -901,7 +899,7 @@ GraphGraphicsItem::GraphGraphicsItem(StepCore::Item* item, WorldModel* worldMode
     Q_ASSERT(dynamic_cast<StepCore::Graph*>(_item) != NULL);
     setFlag(QGraphicsItem::ItemIsSelectable);
     setFlag(QGraphicsItem::ItemIsMovable);
-    setAcceptsHoverEvents(true);
+    setAcceptHoverEvents(true);
 
     _plotWidget = new KPlotWidget();
     _plotWidget->setPalette(QPalette(Qt::lightGray));
@@ -1158,10 +1156,10 @@ void GraphMenuHandler::configureGraph()
     connect(_confUi->dataSourceY, SIGNAL(dataSourceChanged()), this, SLOT(confChanged()));
     connect(_confUi->checkBoxAutoX, SIGNAL(stateChanged(int)), this, SLOT(confChanged()));
     connect(_confUi->checkBoxAutoY, SIGNAL(stateChanged(int)), this, SLOT(confChanged()));
-    connect(_confUi->lineEditMinX, SIGNAL(textEdited(const QString&)), this, SLOT(confChanged()));
-    connect(_confUi->lineEditMaxX, SIGNAL(textEdited(const QString&)), this, SLOT(confChanged()));
-    connect(_confUi->lineEditMinY, SIGNAL(textEdited(const QString&)), this, SLOT(confChanged()));
-    connect(_confUi->lineEditMaxY, SIGNAL(textEdited(const QString&)), this, SLOT(confChanged()));
+    connect(_confUi->lineEditMinX, SIGNAL(textEdited(QString)), this, SLOT(confChanged()));
+    connect(_confUi->lineEditMaxX, SIGNAL(textEdited(QString)), this, SLOT(confChanged()));
+    connect(_confUi->lineEditMinY, SIGNAL(textEdited(QString)), this, SLOT(confChanged()));
+    connect(_confUi->lineEditMaxY, SIGNAL(textEdited(QString)), this, SLOT(confChanged()));
     connect(_confUi->checkBoxShowLines, SIGNAL(stateChanged(int)), this, SLOT(confChanged()));
     connect(_confUi->checkBoxShowPoints, SIGNAL(stateChanged(int)), this, SLOT(confChanged()));
 
@@ -1247,7 +1245,7 @@ MeterGraphicsItem::MeterGraphicsItem(StepCore::Item* item, WorldModel* worldMode
     Q_ASSERT(dynamic_cast<StepCore::Meter*>(_item) != NULL);
     setFlag(QGraphicsItem::ItemIsSelectable);
     setFlag(QGraphicsItem::ItemIsMovable);
-    setAcceptsHoverEvents(true);
+    setAcceptHoverEvents(true);
     setBackgroundBrush(QBrush(Qt::white));
 
     _widget = new QFrame();
@@ -1362,7 +1360,7 @@ void MeterMenuHandler::configureMeter()
     connect(_buttonBox, SIGNAL(clicked(QAbstractButton*)), this, SLOT(confApply(QAbstractButton*)));
 
     connect(_confUi->dataSource, SIGNAL(dataSourceChanged()), this, SLOT(confChanged()));
-    connect(_confUi->lineEditDigits, SIGNAL(textEdited(const QString&)), this, SLOT(confChanged()));
+    connect(_confUi->lineEditDigits, SIGNAL(textEdited(QString)), this, SLOT(confChanged()));
 
     _confDialog->exec();
 
@@ -1410,7 +1408,7 @@ ControllerGraphicsItem::ControllerGraphicsItem(StepCore::Item* item, WorldModel*
     Q_ASSERT(dynamic_cast<StepCore::Controller*>(_item) != NULL);
     setFlag(QGraphicsItem::ItemIsSelectable);
     setFlag(QGraphicsItem::ItemIsMovable);
-    setAcceptsHoverEvents(true);
+    setAcceptHoverEvents(true);
     setBackgroundBrush(QBrush(Qt::white));
 
     _widget = new QWidget();
@@ -1696,11 +1694,11 @@ void ControllerMenuHandler::configureController()
     connect(_buttonBox, SIGNAL(clicked(QAbstractButton*)), this, SLOT(confApply(QAbstractButton*)));
 
     connect(_confUi->dataSource, SIGNAL(dataSourceChanged()), this, SLOT(confChanged()));
-    connect(_confUi->lineEditMin, SIGNAL(textEdited(const QString&)), this, SLOT(confChanged()));
-    connect(_confUi->lineEditMax, SIGNAL(textEdited(const QString&)), this, SLOT(confChanged()));
-    connect(_confUi->keyIncrease, SIGNAL(keySequenceChanged(const QKeySequence&)), this, SLOT(confChanged()));
-    connect(_confUi->keyDecrease, SIGNAL(keySequenceChanged(const QKeySequence&)), this, SLOT(confChanged()));
-    connect(_confUi->lineEditIncrement, SIGNAL(textEdited(const QString&)), this, SLOT(confChanged()));
+    connect(_confUi->lineEditMin, SIGNAL(textEdited(QString)), this, SLOT(confChanged()));
+    connect(_confUi->lineEditMax, SIGNAL(textEdited(QString)), this, SLOT(confChanged()));
+    connect(_confUi->keyIncrease, SIGNAL(keySequenceChanged(QKeySequence)), this, SLOT(confChanged()));
+    connect(_confUi->keyDecrease, SIGNAL(keySequenceChanged(QKeySequence)), this, SLOT(confChanged()));
+    connect(_confUi->lineEditIncrement, SIGNAL(textEdited(QString)), this, SLOT(confChanged()));
 
     _confDialog->exec();
 
